# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: scalekit/v1/commons/commons.proto
# Protobuf Python Version: 5.26.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.api import visibility_pb2 as google_dot_api_dot_visibility__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from protoc_gen_openapiv2.options import annotations_pb2 as protoc__gen__openapiv2_dot_options_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!scalekit/v1/commons/commons.proto\x12\x13scalekit.v1.commons\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/api/visibility.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a.protoc-gen-openapiv2/options/annotations.proto\"\xb9\x0b\n\x16OrganizationMembership\x12\x86\x01\n\x0forganization_id\x18\x01 \x01(\tB]\x92\x41Z2@Unique identifier for the organization. Immutable and read-only.J\x16\"org_1234abcd5678efgh\"R\x0eorganizationId\x12\x89\x01\n\tjoin_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampBP\x92\x41M2KTimestamp when the membership was created. Automatically set by the server.R\x08joinTime\x12R\n\x11membership_status\x18\x03 \x01(\x0e\x32%.scalekit.v1.commons.MembershipStatusR\x10membershipStatus\x12/\n\x05roles\x18\x04 \x03(\x0b\x32\x19.scalekit.v1.commons.RoleR\x05roles\x12Q\n\x04name\x18\x05 \x01(\tB8\x92\x41\x35\x32\'Display name for the Organization name.J\n\"AcmeCorp\"H\x00R\x04name\x88\x01\x01\x12\x94\x02\n\x08metadata\x18\x07 \x03(\x0b\x32\x39.scalekit.v1.commons.OrganizationMembership.MetadataEntryB\xbc\x01\x92\x41\x9f\x01\x32\x64\x43ustom key-value pairs for storing additional user context. Keys (3-25 chars), values (1-256 chars).J7{\"department\": \"engineering\", \"location\": \"nyc-office\"}\xbaH\x16\x9a\x01\x13\x10\x14\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x12`\n\x0c\x64isplay_name\x18\t \x01(\tB8\x92\x41\x35\x32\'Display name for the Organization name.J\n\"AcmeCorp\"H\x01R\x0b\x64isplayName\x88\x01\x01\x12N\n\ninvited_by\x18\n \x01(\tB*\x92\x41\'2%ID of the user who invited this user.H\x02R\tinvitedBy\x88\x01\x01\x12o\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampB/\x92\x41,2*Timestamp when the invitation was created.H\x03R\tcreatedAt\x88\x01\x01\x12w\n\x0b\x61\x63\x63\x65pted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.TimestampB5\x92\x41\x32\x32\x30Timestamp when the user accepted the invitation.H\x04R\nacceptedAt\x88\x01\x01\x12k\n\nexpires_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.TimestampB+\x92\x41(2&Timestamp when the invitation expired.H\x05R\texpiresAt\x88\x01\x01\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\x07\n\x05_nameB\x0f\n\r_display_nameB\r\n\x0b_invited_byB\r\n\x0b_created_atB\x0e\n\x0c_accepted_atB\r\n\x0b_expires_at\"\xe0\x01\n\x04Role\x12\x39\n\x02id\x18\x01 \x01(\tB)\x92\x41#2\x07Role IDJ\x18\"role_79643236410327240\"\xe0\x41\x03R\x02id\x12G\n\x04name\x18\x02 \x01(\tB3\x92\x41\x30\x32\"Unique key identifier for the roleJ\n\"team_dev\"R\x04name\x12T\n\x0c\x64isplay_name\x18\x03 \x01(\tB1\x92\x41.2 Human-readable name for the roleJ\n\"Dev Team\"R\x0b\x64isplayName\"\x99\x0c\n\x0bUserProfile\x12\x89\x01\n\x02id\x18\x01 \x01(\tBy\x92\x41s2QUnique system-generated identifier for the user profile. Immutable and read-only.J\x1e\"usr_profile_1234abcd5678efgh\"\xe0\x41\x03R\x02id\x12^\n\nfirst_name\x18\x02 \x01(\tB?\x92\x41\x34\x32*User\'s given name. Maximum 200 characters.J\x06\"John\"\xbaH\x05r\x03\x18\xc8\x01R\tfirstName\x12\\\n\tlast_name\x18\x03 \x01(\tB?\x92\x41\x34\x32+User\'s family name. Maximum 200 characters.J\x05\"Doe\"\xbaH\x05r\x03\x18\xc8\x01R\x08lastName\x12v\n\x04name\x18\x04 \x01(\tBb\x92\x41_2IFull name in display format. Typically combines first_name and last_name.J\x12\"John Michael Doe\"R\x04name\x12y\n\x06locale\x18\x05 \x01(\tBa\x92\x41^2SUser\'s localization preference in BCP-47 format. Defaults to organization settings.J\x07\"en-US\"R\x06locale\x12\x92\x01\n\x0e\x65mail_verified\x18\x06 \x01(\x08\x42k\x92\x41\x65\x32]Indicates if the user\'s email address has been verified. Automatically updated by the system.J\x04true\xe0\x41\x03R\remailVerified\x12\x8a\x01\n\x0cphone_number\x18\x07 \x01(\tBg\x92\x41\x64\x32RPhone number in E.164 international format. Required for SMS-based authentication.J\x0e\"+14155552671\"R\x0bphoneNumber\x12\x87\x02\n\x08metadata\x18\x08 \x03(\x0b\x32..scalekit.v1.commons.UserProfile.MetadataEntryB\xba\x01\x92\x41\x9d\x01\x32^System-managed key-value pairs for internal tracking. Keys (3-25 chars), values (1-256 chars).J;{\"account_status\": \"active\", \"signup_source\": \"mobile_app\"}\xbaH\x16\x9a\x01\x13\x10\x1e\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x08metadata\x12\x9e\x02\n\x11\x63ustom_attributes\x18\t \x03(\x0b\x32\x36.scalekit.v1.commons.UserProfile.CustomAttributesEntryB\xb8\x01\x92\x41\x9b\x01\x32ZCustom attributes for extended user profile data. Keys (3-25 chars), values (1-256 chars).J={\"department\": \"engineering\", \"security_clearance\": \"level2\"}\xbaH\x16\x9a\x01\x13\x10\x64\"\x06r\x04\x10\x03\x18\x19*\x07r\x05\x10\x01\x18\x80\x02R\x10\x63ustomAttributes\x1a;\n\rMetadataEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x43\n\x15\x43ustomAttributesEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*9\n\nRegionCode\x12\x1b\n\x17REGION_CODE_UNSPECIFIED\x10\x00\x12\x06\n\x02US\x10\x01\x12\x06\n\x02\x45U\x10\x02*E\n\x0f\x45nvironmentType\x12 \n\x1c\x45NVIRONMENT_TYPE_UNSPECIFIED\x10\x00\x12\x07\n\x03PRD\x10\x01\x12\x07\n\x03\x44\x45V\x10\x02*w\n\x10MembershipStatus\x12!\n\x1dMembership_Status_UNSPECIFIED\x10\x00\x12\n\n\x06\x41\x43TIVE\x10\x01\x12\x0c\n\x08INACTIVE\x10\x02\x12\x12\n\x0ePENDING_INVITE\x10\x03\x12\x12\n\x0eINVITE_EXPIRED\x10\x04*\x98\x02\n\x14IdentityProviderType\x12!\n\x1dIDENTITY_PROVIDER_UNSPECIFIED\x10\x00\x12\x08\n\x04OKTA\x10\x01\x12\n\n\x06GOOGLE\x10\x02\x12\x10\n\x0cMICROSOFT_AD\x10\x03\x12\t\n\x05\x41UTH0\x10\x04\x12\x0c\n\x08ONELOGIN\x10\x05\x12\x11\n\rPING_IDENTITY\x10\x06\x12\r\n\tJUMPCLOUD\x10\x07\x12\n\n\x06\x43USTOM\x10\x08\x12\n\n\x06GITHUB\x10\t\x12\n\n\x06GITLAB\x10\n\x12\x0c\n\x08LINKEDIN\x10\x0b\x12\x0e\n\nSALESFORCE\x10\x0c\x12\r\n\tMICROSOFT\x10\r\x12\x11\n\rIDP_SIMULATOR\x10\x0e\x12\x0c\n\x08SCALEKIT\x10\x0f\x12\x08\n\x04\x41\x44\x46S\x10\x10\x42\x33Z1github.com/scalekit-inc/scalekit/pkg/grpc/commonsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'scalekit.v1.commons.commons_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z1github.com/scalekit-inc/scalekit/pkg/grpc/commons'
  _globals['_ORGANIZATIONMEMBERSHIP_METADATAENTRY']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['organization_id']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['organization_id']._serialized_options = b'\222AZ2@Unique identifier for the organization. Immutable and read-only.J\026\"org_1234abcd5678efgh\"'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['join_time']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['join_time']._serialized_options = b'\222AM2KTimestamp when the membership was created. Automatically set by the server.'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['name']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['name']._serialized_options = b'\222A52\'Display name for the Organization name.J\n\"AcmeCorp\"'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['metadata']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['metadata']._serialized_options = b'\222A\237\0012dCustom key-value pairs for storing additional user context. Keys (3-25 chars), values (1-256 chars).J7{\"department\": \"engineering\", \"location\": \"nyc-office\"}\272H\026\232\001\023\020\024\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['display_name']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['display_name']._serialized_options = b'\222A52\'Display name for the Organization name.J\n\"AcmeCorp\"'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['invited_by']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['invited_by']._serialized_options = b'\222A\'2%ID of the user who invited this user.'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['created_at']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['created_at']._serialized_options = b'\222A,2*Timestamp when the invitation was created.'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['accepted_at']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['accepted_at']._serialized_options = b'\222A220Timestamp when the user accepted the invitation.'
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['expires_at']._loaded_options = None
  _globals['_ORGANIZATIONMEMBERSHIP'].fields_by_name['expires_at']._serialized_options = b'\222A(2&Timestamp when the invitation expired.'
  _globals['_ROLE'].fields_by_name['id']._loaded_options = None
  _globals['_ROLE'].fields_by_name['id']._serialized_options = b'\222A#2\007Role IDJ\030\"role_79643236410327240\"\340A\003'
  _globals['_ROLE'].fields_by_name['name']._loaded_options = None
  _globals['_ROLE'].fields_by_name['name']._serialized_options = b'\222A02\"Unique key identifier for the roleJ\n\"team_dev\"'
  _globals['_ROLE'].fields_by_name['display_name']._loaded_options = None
  _globals['_ROLE'].fields_by_name['display_name']._serialized_options = b'\222A.2 Human-readable name for the roleJ\n\"Dev Team\"'
  _globals['_USERPROFILE_METADATAENTRY']._loaded_options = None
  _globals['_USERPROFILE_METADATAENTRY']._serialized_options = b'8\001'
  _globals['_USERPROFILE_CUSTOMATTRIBUTESENTRY']._loaded_options = None
  _globals['_USERPROFILE_CUSTOMATTRIBUTESENTRY']._serialized_options = b'8\001'
  _globals['_USERPROFILE'].fields_by_name['id']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['id']._serialized_options = b'\222As2QUnique system-generated identifier for the user profile. Immutable and read-only.J\036\"usr_profile_1234abcd5678efgh\"\340A\003'
  _globals['_USERPROFILE'].fields_by_name['first_name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['first_name']._serialized_options = b'\222A42*User\'s given name. Maximum 200 characters.J\006\"John\"\272H\005r\003\030\310\001'
  _globals['_USERPROFILE'].fields_by_name['last_name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['last_name']._serialized_options = b'\222A42+User\'s family name. Maximum 200 characters.J\005\"Doe\"\272H\005r\003\030\310\001'
  _globals['_USERPROFILE'].fields_by_name['name']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['name']._serialized_options = b'\222A_2IFull name in display format. Typically combines first_name and last_name.J\022\"John Michael Doe\"'
  _globals['_USERPROFILE'].fields_by_name['locale']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['locale']._serialized_options = b'\222A^2SUser\'s localization preference in BCP-47 format. Defaults to organization settings.J\007\"en-US\"'
  _globals['_USERPROFILE'].fields_by_name['email_verified']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['email_verified']._serialized_options = b'\222Ae2]Indicates if the user\'s email address has been verified. Automatically updated by the system.J\004true\340A\003'
  _globals['_USERPROFILE'].fields_by_name['phone_number']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['phone_number']._serialized_options = b'\222Ad2RPhone number in E.164 international format. Required for SMS-based authentication.J\016\"+14155552671\"'
  _globals['_USERPROFILE'].fields_by_name['metadata']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['metadata']._serialized_options = b'\222A\235\0012^System-managed key-value pairs for internal tracking. Keys (3-25 chars), values (1-256 chars).J;{\"account_status\": \"active\", \"signup_source\": \"mobile_app\"}\272H\026\232\001\023\020\036\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_USERPROFILE'].fields_by_name['custom_attributes']._loaded_options = None
  _globals['_USERPROFILE'].fields_by_name['custom_attributes']._serialized_options = b'\222A\233\0012ZCustom attributes for extended user profile data. Keys (3-25 chars), values (1-256 chars).J={\"department\": \"engineering\", \"security_clearance\": \"level2\"}\272H\026\232\001\023\020d\"\006r\004\020\003\030\031*\007r\005\020\001\030\200\002'
  _globals['_REGIONCODE']._serialized_start=3607
  _globals['_REGIONCODE']._serialized_end=3664
  _globals['_ENVIRONMENTTYPE']._serialized_start=3666
  _globals['_ENVIRONMENTTYPE']._serialized_end=3735
  _globals['_MEMBERSHIPSTATUS']._serialized_start=3737
  _globals['_MEMBERSHIPSTATUS']._serialized_end=3856
  _globals['_IDENTITYPROVIDERTYPE']._serialized_start=3859
  _globals['_IDENTITYPROVIDERTYPE']._serialized_end=4139
  _globals['_ORGANIZATIONMEMBERSHIP']._serialized_start=349
  _globals['_ORGANIZATIONMEMBERSHIP']._serialized_end=1814
  _globals['_ORGANIZATIONMEMBERSHIP_METADATAENTRY']._serialized_start=1668
  _globals['_ORGANIZATIONMEMBERSHIP_METADATAENTRY']._serialized_end=1727
  _globals['_ROLE']._serialized_start=1817
  _globals['_ROLE']._serialized_end=2041
  _globals['_USERPROFILE']._serialized_start=2044
  _globals['_USERPROFILE']._serialized_end=3605
  _globals['_USERPROFILE_METADATAENTRY']._serialized_start=1668
  _globals['_USERPROFILE_METADATAENTRY']._serialized_end=1727
  _globals['_USERPROFILE_CUSTOMATTRIBUTESENTRY']._serialized_start=3538
  _globals['_USERPROFILE_CUSTOMATTRIBUTESENTRY']._serialized_end=3605
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from scalekit.v1.auth import passwordless_pb2 as scalekit_dot_v1_dot_auth_dot_passwordless__pb2


class PasswordlessServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendPasswordlessEmail = channel.unary_unary(
                '/scalekit.v1.auth.passwordless.PasswordlessService/SendPasswordlessEmail',
                request_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
                )
        self.VerifyPasswordlessEmail = channel.unary_unary(
                '/scalekit.v1.auth.passwordless.PasswordlessService/VerifyPasswordlessEmail',
                request_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessResponse.FromString,
                )
        self.ResendPasswordlessEmail = channel.unary_unary(
                '/scalekit.v1.auth.passwordless.PasswordlessService/ResendPasswordlessEmail',
                request_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.ResendPasswordlessRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
                )


class PasswordlessServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendPasswordlessEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def VerifyPasswordlessEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ResendPasswordlessEmail(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PasswordlessServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendPasswordlessEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.SendPasswordlessEmail,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.SerializeToString,
            ),
            'VerifyPasswordlessEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.VerifyPasswordlessEmail,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessResponse.SerializeToString,
            ),
            'ResendPasswordlessEmail': grpc.unary_unary_rpc_method_handler(
                    servicer.ResendPasswordlessEmail,
                    request_deserializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.ResendPasswordlessRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.auth.passwordless.PasswordlessService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class PasswordlessService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendPasswordlessEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.passwordless.PasswordlessService/SendPasswordlessEmail',
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def VerifyPasswordlessEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.passwordless.PasswordlessService/VerifyPasswordlessEmail',
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.VerifyPasswordLessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ResendPasswordlessEmail(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.auth.passwordless.PasswordlessService/ResendPasswordlessEmail',
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.ResendPasswordlessRequest.SerializeToString,
            scalekit_dot_v1_dot_auth_dot_passwordless__pb2.SendPasswordlessResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from typing import Optional

from scalekit.core import CoreClient
from scalekit.v1.roles.roles_pb2 import *
from scalekit.v1.roles.roles_pb2_grpc import RolesServiceStub


class RoleClient:
    """Class definition for Role Client"""

    def __init__(self, core_client: CoreClient):
        """
        Initializer for Role Client

        :param core_client    : CoreClient Object
        :type                 : ``` obj ```
        :returns
            None
        """
        self.core_client = core_client
        self.role_service = RolesServiceStub(
            self.core_client.grpc_secure_channel
        )

    def create_role(
        self, 
        role: CreateRole
    ) -> CreateRoleResponse:
        """
        Method to create a new role

        :param role           : CreateRole object with expected values for role creation
        :type                 : ``` obj ```

        :returns:
            Create Role Response
        """
        return self.core_client.grpc_exec(
            self.role_service.CreateRole.with_call,
            CreateRoleRequest(role=role),
        )

    def get_role(self, role_id: str) -> GetRoleResponse:
        """
        Method to get role by ID

        :param role_id        : Role id to get role details
        :type                 : ``` str ```

        :returns:
            Get Role Response
        """
        return self.core_client.grpc_exec(
            self.role_service.GetRole.with_call,
            GetRoleRequest(id=role_id),
        )

    def list_roles(self) -> ListRolesResponse:
        """
        Method to list all roles

        :returns:
            List Roles Response
        """
        return self.core_client.grpc_exec(
            self.role_service.ListRoles.with_call,
            ListRolesRequest(),
        )

    def update_role(
        self, 
        role_id: str, 
        role: UpdateRole
    ) -> UpdateRoleResponse:
        """
        Method to update an existing role by ID

        :param role_id        : Role id to update
        :type                 : ``` str ```
        :param role           : UpdateRole object with expected values for role update
        :type                 : ``` obj ```

        :returns:
            Update Role Response
        """
        return self.core_client.grpc_exec(
            self.role_service.UpdateRole.with_call,
            UpdateRoleRequest(
                id=role_id,
                role=role
            ),
        )

    def delete_role(
        self, 
        role_id: str, 
        reassign_role_id: Optional[str] = None
    ):
        """
        Method to delete role by ID

        :param role_id        : Role id to be deleted
        :type                 : ``` str ```
        :param reassign_role_id: Role ID to reassign users to when deleting this role
        :type                 : ``` str ```

        :returns:
            None
        """
        request = DeleteRoleRequest(id=role_id)
        if reassign_role_id:
            request.reassign_role_id = reassign_role_id
            
        return self.core_client.grpc_exec(
            self.role_service.DeleteRole.with_call,
            request,
        )

    def get_role_users_count(
        self, 
        role_id: str
    ) -> GetRoleUsersCountResponse:
        """
        Method to get the count of users associated with a role

        :param role_id        : Role id to get user count for
        :type                 : ``` str ```

        :returns:
            Get Role Users Count Response
        """
        return self.core_client.grpc_exec(
            self.role_service.GetRoleUsersCount.with_call,
            GetRoleUsersCountRequest(id=role_id),
        )

 


from typing import Optional

from scalekit.core import CoreClient
from scalekit.v1.users.users_pb2 import *
from scalekit.v1.users.users_pb2_grpc import UserServiceStub


class UserClient:
    """Class definition for User Client"""

    def __init__(self, core_client: CoreClient):
        """
        Initializer for User Client

        :param core_client    : CoreClient Object
        :type                 : ``` obj ```
        :returns
            None
        """
        self.core_client = core_client
        self.user_service = UserServiceStub(
            self.core_client.grpc_secure_channel
        )

    def create_user_and_membership(
        self, 
        organization_id: str, 
        user: CreateUser, 
        send_invitation_email: bool = True
    ) -> CreateUserAndMembershipResponse:
        """
        Method to create a new user and add them to an organization

        :param organization_id      : Organization id to create user for
        :type                       : ``` str ```
        :param user                : CreateUser object with expected values for user creation
        :type                       : ``` obj ```
        :param send_invitation_email: Whether to send activation email to the user
        :type                       : ``` bool ```

        :returns:
            Create User And Membership Response
        """
        return self.core_client.grpc_exec(
            self.user_service.CreateUserAndMembership.with_call,
            CreateUserAndMembershipRequest(
                organization_id=organization_id,
                user=user,
                send_invitation_email=send_invitation_email
            ),
        )

    def get_user(self, user_id: str) -> GetUserResponse:
        """
        Method to get user by ID

        :param user_id         : User id to get user details
        :type                  : ``` str ```

        :returns:
            Get User Response
        """
        return self.core_client.grpc_exec(
            self.user_service.GetUser.with_call,
            GetUserRequest(id=user_id),
        )

    def get_user_by_external_id(self, external_id: str) -> GetUserResponse:
        """
        Method to get user by external ID

        :param external_id     : External id to get user details
        :type                  : ``` str ```

        :returns:
            Get User Response
        """
        return self.core_client.grpc_exec(
            self.user_service.GetUser.with_call,
            GetUserRequest(external_id=external_id),
        )

    def list_users(
        self,
        page_size: Optional[int] = None,
        page_token: Optional[str] = None
    ) -> ListUsersResponse:
        """
        Method to list all users in environment

        :param page_size       : Page size for pagination
        :type                  : ``` int ```
        :param page_token      : Page token for pagination
        :type                  : ``` str ```

        :returns:
            List Users Response
        """
        return self.core_client.grpc_exec(
            self.user_service.ListUsers.with_call,
            ListUsersRequest(
                page_size=page_size,
                page_token=page_token
            ),
        )

    def list_organization_users(
        self,
        organization_id: str,
        page_size: Optional[int] = None,
        page_token: Optional[str] = None
    ) -> ListOrganizationUsersResponse:
        """
        Method to list users for given organization id

        :param organization_id  : Organization id to list users for
        :type                   : ``` str ```
        :param page_size       : Page size for pagination
        :type                   : ``` int ```
        :param page_token      : Page token for pagination
        :type                   : ``` str ```

        :returns:
            List Organization Users Response
        """
        return self.core_client.grpc_exec(
            self.user_service.ListOrganizationUsers.with_call,
            ListOrganizationUsersRequest(
                organization_id=organization_id,
                page_size=page_size,
                page_token=page_token
            ),
        )

    def update_user(self, user_id: str, user: UpdateUser) -> UpdateUserResponse:
        """
        Method to update an existing user by ID

        :param user_id         : User id to update
        :type                  : ``` str ```
        :param user            : UpdateUser object with expected values for user update
        :type                  : ``` obj ```

        :returns:
            Update User Response
        """
        return self.core_client.grpc_exec(
            self.user_service.UpdateUser.with_call,
            UpdateUserRequest(id=user_id, user=user),
        )

    def update_user_by_external_id(self, external_id: str, user: UpdateUser) -> UpdateUserResponse:
        """
        Method to update an existing user by external ID

        :param external_id     : External id to update
        :type                  : ``` str ```
        :param user            : UpdateUser object with expected values for user update
        :type                  : ``` obj ```

        :returns:
            Update User Response
        """
        return self.core_client.grpc_exec(
            self.user_service.UpdateUser.with_call,
            UpdateUserRequest(external_id=external_id, user=user),
        )

    def delete_user(self, user_id: str):
        """
        Method to delete user by ID

        :param user_id         : User id to be deleted
        :type                  : ``` str ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.user_service.DeleteUser.with_call,
            DeleteUserRequest(id=user_id),
        )

    def delete_user_by_external_id(self, external_id: str):
        """
        Method to delete user by external ID

        :param external_id     : External id to be deleted
        :type                  : ``` str ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.user_service.DeleteUser.with_call,
            DeleteUserRequest(external_id=external_id),
        )

    def create_membership(
        self,
        organization_id: str,
        user_id: str,
        membership: CreateMembership,
        send_invitation_email: bool = True
    ) -> CreateMembershipResponse:
        """
        Method to create a membership for a user by user ID

        :param organization_id  : Organization id
        :type                   : ``` str ```
        :param user_id          : User id
        :type                   : ``` str ```
        :param membership       : CreateMembership object
        :type                   : ``` obj ```
        :param send_invitation_email: Whether to send activation email to the user
        :type                       : ``` bool ```

        :returns:
            Create Membership Response
        """
        return self.core_client.grpc_exec(
            self.user_service.CreateMembership.with_call,
            CreateMembershipRequest(
                organization_id=organization_id,
                id=user_id,
                membership=membership,
                send_invitation_email=send_invitation_email
            ),
        )

    def create_membership_by_external_id(
        self,
        organization_id: str,
        external_id: str,
        membership: CreateMembership,
        send_invitation_email: bool = True
    ) -> CreateMembershipResponse:
        """
        Method to create a membership for a user by external ID

        :param organization_id  : Organization id
        :type                   : ``` str ```
        :param external_id      : External id
        :type                   : ``` str ```
        :param membership       : CreateMembership object
        :type                   : ``` obj ```
        :param send_invitation_email: Whether to send activation email to the user
        :type                       : ``` bool ```

        :returns:
            Create Membership Response
        """
        return self.core_client.grpc_exec(
            self.user_service.CreateMembership.with_call,
            CreateMembershipRequest(
                organization_id=organization_id,
                external_id=external_id,
                membership=membership,
                send_invitation_email=send_invitation_email
            ),
        )

    def update_membership(
        self,
        organization_id: str,
        user_id: str,
        membership: UpdateMembership
    ) -> UpdateMembershipResponse:
        """
        Method to update a membership for a user by user ID

        :param organization_id  : Organization id
        :type                   : ``` str ```
        :param user_id          : User id
        :type                   : ``` str ```
        :param membership       : UpdateMembership object
        :type                   : ``` obj ```

        :returns:
            Update Membership Response
        """
        return self.core_client.grpc_exec(
            self.user_service.UpdateMembership.with_call,
            UpdateMembershipRequest(
                organization_id=organization_id,
                id=user_id,
                membership=membership
            ),
        )

    def update_membership_by_external_id(
        self,
        organization_id: str,
        external_id: str,
        membership: UpdateMembership
    ) -> UpdateMembershipResponse:
        """
        Method to update a membership for a user by external ID

        :param organization_id  : Organization id
        :type                   : ``` str ```
        :param external_id      : External id
        :type                   : ``` str ```
        :param membership       : UpdateMembership object
        :type                   : ``` obj ```

        :returns:
            Update Membership Response
        """
        return self.core_client.grpc_exec(
            self.user_service.UpdateMembership.with_call,
            UpdateMembershipRequest(
                organization_id=organization_id,
                external_id=external_id,
                membership=membership
            ),
        )

    def delete_membership(
        self,
        organization_id: str,
        user_id: str
    ):
        """
        Method to delete a membership for a user by user ID

        :param organization_id  : Organization id
        :type                   : ``` str ```
        :param user_id          : User id
        :type                   : ``` str ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.user_service.DeleteMembership.with_call,
            DeleteMembershipRequest(
                organization_id=organization_id,
                id=user_id
            ),
        )

    def delete_membership_by_external_id(
        self,
        organization_id: str,
        external_id: str
    ):
        """
        Method to delete a membership for a user by external ID

        :param organization_id  : Organization id
        :type                   : ``` str ```
        :param external_id      : External id
        :type                   : ``` str ```

        :returns:
            None
        """
        return self.core_client.grpc_exec(
            self.user_service.DeleteMembership.with_call,
            DeleteMembershipRequest(
                organization_id=organization_id,
                external_id=external_id
            ),
        )

   



from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.api import field_behavior_pb2 as _field_behavior_pb2
from google.protobuf import empty_pb2 as _empty_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from protoc_gen_openapiv2.options import annotations_pb2 as _annotations_pb2_1
from scalekit.v1.commons import commons_pb2 as _commons_pb2
from scalekit.v1.options import options_pb2 as _options_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class TemplateType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    UNSPECIFIED: _ClassVar[TemplateType]
    SIGNIN: _ClassVar[TemplateType]
    SIGNUP: _ClassVar[TemplateType]

class PasswordlessType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    PASSWORDLESS_TYPE_UNSPECIFIED: _ClassVar[PasswordlessType]
    OTP: _ClassVar[PasswordlessType]
    LINK: _ClassVar[PasswordlessType]
    LINK_OTP: _ClassVar[PasswordlessType]
UNSPECIFIED: TemplateType
SIGNIN: TemplateType
SIGNUP: TemplateType
PASSWORDLESS_TYPE_UNSPECIFIED: PasswordlessType
OTP: PasswordlessType
LINK: PasswordlessType
LINK_OTP: PasswordlessType

class SendPasswordlessRequest(_message.Message):
    __slots__ = ("email", "template", "magiclink_auth_uri", "state", "expires_in", "template_variables")
    class TemplateVariablesEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    MAGICLINK_AUTH_URI_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_VARIABLES_FIELD_NUMBER: _ClassVar[int]
    email: str
    template: TemplateType
    magiclink_auth_uri: str
    state: str
    expires_in: int
    template_variables: _containers.ScalarMap[str, str]
    def __init__(self, email: _Optional[str] = ..., template: _Optional[_Union[TemplateType, str]] = ..., magiclink_auth_uri: _Optional[str] = ..., state: _Optional[str] = ..., expires_in: _Optional[int] = ..., template_variables: _Optional[_Mapping[str, str]] = ...) -> None: ...

class SendPasswordlessResponse(_message.Message):
    __slots__ = ("auth_request_id", "expires_at", "expires_in", "passwordless_type")
    AUTH_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    PASSWORDLESS_TYPE_FIELD_NUMBER: _ClassVar[int]
    auth_request_id: str
    expires_at: int
    expires_in: int
    passwordless_type: PasswordlessType
    def __init__(self, auth_request_id: _Optional[str] = ..., expires_at: _Optional[int] = ..., expires_in: _Optional[int] = ..., passwordless_type: _Optional[_Union[PasswordlessType, str]] = ...) -> None: ...

class VerifyPasswordLessRequest(_message.Message):
    __slots__ = ("code", "link_token", "auth_request_id")
    CODE_FIELD_NUMBER: _ClassVar[int]
    LINK_TOKEN_FIELD_NUMBER: _ClassVar[int]
    AUTH_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    code: str
    link_token: str
    auth_request_id: str
    def __init__(self, code: _Optional[str] = ..., link_token: _Optional[str] = ..., auth_request_id: _Optional[str] = ...) -> None: ...

class ResendPasswordlessRequest(_message.Message):
    __slots__ = ("auth_request_id",)
    AUTH_REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    auth_request_id: str
    def __init__(self, auth_request_id: _Optional[str] = ...) -> None: ...

class VerifyPasswordLessResponse(_message.Message):
    __slots__ = ("email", "state", "template", "passwordless_type")
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    TEMPLATE_FIELD_NUMBER: _ClassVar[int]
    PASSWORDLESS_TYPE_FIELD_NUMBER: _ClassVar[int]
    email: str
    state: str
    template: TemplateType
    passwordless_type: PasswordlessType
    def __init__(self, email: _Optional[str] = ..., state: _Optional[str] = ..., template: _Optional[_Union[TemplateType, str]] = ..., passwordless_type: _Optional[_Union[PasswordlessType, str]] = ...) -> None: ...



from .models.requests.tool_request import ToolRequest
from .models.requests.mcp_request import McpRequest
from .models.requests.create_connected_account_request import CreateConnectedAccountRequest
from .models.responses.execute_tool_response import ExecuteToolResponse
from .models.responses.magic_link_response import MagicLinkResponse
from .models.responses.list_connected_accounts_response import ListConnectedAccountsResponse
from .models.responses.delete_connected_account_response import DeleteConnectedAccountResponse
from .models.responses.get_connected_account_auth_response import GetConnectedAccountAuthResponse
from .models.responses.create_connected_account_response import CreateConnectedAccountResponse
from .models.responses.create_mcp_response import CreateMcpResponse
from .models.responses.get_mcp_response import GetMcpResponse
from .models.tool_input_output import ToolInput, ToolOutput
from .models.tool_mapping import ToolMapping


__all__ = [
    'ToolRequest',
    'McpRequest',
    'CreateConnectedAccountRequest',
    'ExecuteToolResponse',
    'MagicLinkResponse',
    'ListConnectedAccountsResponse',
    'DeleteConnectedAccountResponse',
    'GetConnectedAccountAuthResponse',
    'CreateConnectedAccountResponse',
    'CreateMcpResponse',
    'GetMcpResponse',
    'ToolInput',
    'ToolOutput',
    'ToolMapping',
]


from typing import Optional
from pydantic import BaseModel, Field, field_validator


class ToolRequest(BaseModel):
    """Tool request configuration with validation"""
    
    tool_version: Optional[str] = Field(
        None, 
        description="Version of the tool to use",
        min_length=1,
        max_length=50
    )
    tool_name: Optional[str] = Field(
        None, 
        description="Name of the tool",
        min_length=1,
        max_length=100
    )
    identifier: Optional[str] = Field(
        None, 
        description="Unique identifier for execution",
        min_length=1,
        max_length=255
    )

    @field_validator('tool_version')
    @classmethod
    def validate_tool_version(cls, v):
        """Validate tool version format"""
        if v is not None:
            if not isinstance(v, str):
                raise ValueError('tool_version must be a string')
            v = v.strip()
            if not v:
                raise ValueError('tool_version cannot be empty or whitespace only')
            # Basic semantic version validation (optional)
            if '.' in v and not all(part.isdigit() for part in v.split('.')):
                raise ValueError('tool_version should follow semantic versioning (e.g., 1.0.0)')
        return v

    @field_validator('tool_name')
    @classmethod
    def validate_tool_name(cls, v):
        """Validate tool name format"""
        if v is not None:
            if not isinstance(v, str):
                raise ValueError('tool_name must be a string')
            v = v.strip()
            if not v:
                raise ValueError('tool_name cannot be empty or whitespace only')
            # Tool name should contain valid characters
            if not all(c.isalnum() or c in '.-_' for c in v):
                raise ValueError('tool_name can only contain alphanumeric characters, dots, hyphens, and underscores')
        return v

    @field_validator('identifier')
    @classmethod
    def validate_identifier(cls, v):
        """Validate identifier format"""
        if v is not None:
            if not isinstance(v, str):
                raise ValueError('identifier must be a string')
            v = v.strip()
            if not v:
                raise ValueError('identifier cannot be empty or whitespace only')
            # Identifier should be alphanumeric with some special characters
            if not all(c.isalnum() or c in '-_.' for c in v):
                raise ValueError('identifier can only contain alphanumeric characters, hyphens, underscores, and dots')
        return v

    class Config:
        """Pydantic configuration"""
        validate_assignment = True
        str_strip_whitespace = True
        use_enum_values = True


# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from scalekit.v1.tools import tools_pb2 as scalekit_dot_v1_dot_tools_dot_tools__pb2


class ToolServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.CreateTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/CreateTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolResponse.FromString,
                )
        self.ListTools = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/ListTools',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsResponse.FromString,
                )
        self.ListScopedTools = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/ListScopedTools',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsResponse.FromString,
                )
        self.SetToolDefault = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/SetToolDefault',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultResponse.FromString,
                )
        self.UpdateTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/UpdateTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolResponse.FromString,
                )
        self.DeleteTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/DeleteTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.DeleteToolRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.ExecuteTool = channel.unary_unary(
                '/scalekit.v1.tools.ToolService/ExecuteTool',
                request_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolRequest.SerializeToString,
                response_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolResponse.FromString,
                )


class ToolServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def CreateTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListScopedTools(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def SetToolDefault(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def UpdateTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DeleteTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExecuteTool(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ToolServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'CreateTool': grpc.unary_unary_rpc_method_handler(
                    servicer.CreateTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolResponse.SerializeToString,
            ),
            'ListTools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListTools,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsResponse.SerializeToString,
            ),
            'ListScopedTools': grpc.unary_unary_rpc_method_handler(
                    servicer.ListScopedTools,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsResponse.SerializeToString,
            ),
            'SetToolDefault': grpc.unary_unary_rpc_method_handler(
                    servicer.SetToolDefault,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultResponse.SerializeToString,
            ),
            'UpdateTool': grpc.unary_unary_rpc_method_handler(
                    servicer.UpdateTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolResponse.SerializeToString,
            ),
            'DeleteTool': grpc.unary_unary_rpc_method_handler(
                    servicer.DeleteTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.DeleteToolRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'ExecuteTool': grpc.unary_unary_rpc_method_handler(
                    servicer.ExecuteTool,
                    request_deserializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolRequest.FromString,
                    response_serializer=scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'scalekit.v1.tools.ToolService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ToolService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def CreateTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/CreateTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.CreateToolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListTools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/ListTools',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListToolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ListScopedTools(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/ListScopedTools',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ListScopedToolsResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def SetToolDefault(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/SetToolDefault',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.SetToolDefaultResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def UpdateTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/UpdateTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.UpdateToolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DeleteTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/DeleteTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.DeleteToolRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def ExecuteTool(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/scalekit.v1.tools.ToolService/ExecuteTool',
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolRequest.SerializeToString,
            scalekit_dot_v1_dot_tools_dot_tools__pb2.ExecuteToolResponse.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



from google.protobuf import duration_pb2 as _duration_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ErrorInfo(_message.Message):
    __slots__ = ("error_code", "debug_info", "help_info", "localized_message_info", "resource_info", "request_info", "validation_error_info", "tool_error_info")
    ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    DEBUG_INFO_FIELD_NUMBER: _ClassVar[int]
    HELP_INFO_FIELD_NUMBER: _ClassVar[int]
    LOCALIZED_MESSAGE_INFO_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_INFO_FIELD_NUMBER: _ClassVar[int]
    REQUEST_INFO_FIELD_NUMBER: _ClassVar[int]
    VALIDATION_ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    TOOL_ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    error_code: str
    debug_info: DebugInfo
    help_info: HelpInfo
    localized_message_info: LocalizedMessageInfo
    resource_info: ResourceInfo
    request_info: RequestInfo
    validation_error_info: ValidationErrorInfo
    tool_error_info: ToolErrorInfo
    def __init__(self, error_code: _Optional[str] = ..., debug_info: _Optional[_Union[DebugInfo, _Mapping]] = ..., help_info: _Optional[_Union[HelpInfo, _Mapping]] = ..., localized_message_info: _Optional[_Union[LocalizedMessageInfo, _Mapping]] = ..., resource_info: _Optional[_Union[ResourceInfo, _Mapping]] = ..., request_info: _Optional[_Union[RequestInfo, _Mapping]] = ..., validation_error_info: _Optional[_Union[ValidationErrorInfo, _Mapping]] = ..., tool_error_info: _Optional[_Union[ToolErrorInfo, _Mapping]] = ...) -> None: ...

class DebugInfo(_message.Message):
    __slots__ = ("stack_entries", "detail")
    STACK_ENTRIES_FIELD_NUMBER: _ClassVar[int]
    DETAIL_FIELD_NUMBER: _ClassVar[int]
    stack_entries: _containers.RepeatedScalarFieldContainer[str]
    detail: str
    def __init__(self, stack_entries: _Optional[_Iterable[str]] = ..., detail: _Optional[str] = ...) -> None: ...

class ValidationErrorInfo(_message.Message):
    __slots__ = ("field_violations",)
    class FieldViolation(_message.Message):
        __slots__ = ("field", "description", "constraint")
        FIELD_FIELD_NUMBER: _ClassVar[int]
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        CONSTRAINT_FIELD_NUMBER: _ClassVar[int]
        field: str
        description: str
        constraint: str
        def __init__(self, field: _Optional[str] = ..., description: _Optional[str] = ..., constraint: _Optional[str] = ...) -> None: ...
    FIELD_VIOLATIONS_FIELD_NUMBER: _ClassVar[int]
    field_violations: _containers.RepeatedCompositeFieldContainer[ValidationErrorInfo.FieldViolation]
    def __init__(self, field_violations: _Optional[_Iterable[_Union[ValidationErrorInfo.FieldViolation, _Mapping]]] = ...) -> None: ...

class RequestInfo(_message.Message):
    __slots__ = ("request_id", "serving_data")
    REQUEST_ID_FIELD_NUMBER: _ClassVar[int]
    SERVING_DATA_FIELD_NUMBER: _ClassVar[int]
    request_id: str
    serving_data: str
    def __init__(self, request_id: _Optional[str] = ..., serving_data: _Optional[str] = ...) -> None: ...

class ResourceInfo(_message.Message):
    __slots__ = ("resource_type", "resource_name", "owner", "description")
    RESOURCE_TYPE_FIELD_NUMBER: _ClassVar[int]
    RESOURCE_NAME_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    resource_type: str
    resource_name: str
    owner: str
    description: str
    def __init__(self, resource_type: _Optional[str] = ..., resource_name: _Optional[str] = ..., owner: _Optional[str] = ..., description: _Optional[str] = ...) -> None: ...

class HelpInfo(_message.Message):
    __slots__ = ("links",)
    class Link(_message.Message):
        __slots__ = ("description", "url")
        DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
        URL_FIELD_NUMBER: _ClassVar[int]
        description: str
        url: str
        def __init__(self, description: _Optional[str] = ..., url: _Optional[str] = ...) -> None: ...
    LINKS_FIELD_NUMBER: _ClassVar[int]
    links: _containers.RepeatedCompositeFieldContainer[HelpInfo.Link]
    def __init__(self, links: _Optional[_Iterable[_Union[HelpInfo.Link, _Mapping]]] = ...) -> None: ...

class LocalizedMessageInfo(_message.Message):
    __slots__ = ("locale", "message")
    LOCALE_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    locale: str
    message: str
    def __init__(self, locale: _Optional[str] = ..., message: _Optional[str] = ...) -> None: ...

class ToolErrorInfo(_message.Message):
    __slots__ = ("execution_id", "tool_error_message", "tool_error_code")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    TOOL_ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TOOL_ERROR_CODE_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    tool_error_message: str
    tool_error_code: str
    def __init__(self, execution_id: _Optional[str] = ..., tool_error_message: _Optional[str] = ..., tool_error_code: _Optional[str] = ...) -> None: ...
